@@ -1,4 +1,4 @@
-// Copyright 2017-2021 Tim McLean
+// Copyright 2017-2022 Tim McLean
 
 //! Comprehensive timing attack protection for Rust programs.
 //!
@@ -21,7 +21,7 @@
 //! page](https://www.chosenplaintext.ca/open-source/rust-timing-shield/getting-started) for more
 //! information.
 
-#![feature(asm, min_specialization)]
+#![feature(min_specialization)]
 
 #[cfg(test)]
 extern crate quickcheck;
@@ -47,7 +47,7 @@ use std::ops::ShrAssign;
 use std::ops::Neg;
 use std::ops::Not;
 
-use barriers::optimization_barrier_u8;
+use crate::barriers::optimization_barrier_u8;
 
 macro_rules! impl_unary_op {
     (
